package de.uni_muenster.tools;

import java.io.BufferedInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;


public class URLCaller extends Thread
{

    private static List queue;
    boolean end = false;

    public void addWorkerURL(PostURL workerURL)
    {
        queue.add(workerURL);
    }

    public void stopWorker()
    {
        end = true;
    }

    public List getQueue()
    {
        return queue;
    }

    public void run()
    {

        while (!end)
        {
            while (queue.isEmpty() && !end)
            {
                try
                {
                    //System.out.println("!!!! QUEUE EMPTY !!!!");
                    System.out.print("E");
                    Thread.currentThread().sleep(500L);
                } catch (InterruptedException ingnore)
                {
                }
            }
            if (end) break;
            PostURL postUrl = (PostURL) queue.remove(0);
            String reply = callHTTPServer(postUrl);
            if (reply.indexOf("ERROR") != -1) System.err.println(reply);
        }
    }

    public URLCaller()
    {
        if (queue == null)
        {
            this.queue = (List) Collections.synchronizedList(new ArrayList());
        }
    }

    /**
     * Call the HTTP Server according to the given URL and get the reply
     *
     * @param url URL to access
     * @return <code>String</code> containing the web server reply (HTML file)
     */
    public String callHTTPServer(PostURL url)
    {
        URL theURL = url.getUrl();
        String parameters = url.getParameters();

        //System.out.println(theURL.toExternalForm().length());
        //System.out.println(url.getUrl().toExternalForm());

        String HTMLReply = "";
        BufferedInputStream in = null;
        StringBuffer stringBuff = null;
        InputStream inputStream = null;

        //i don't think that this loop is necessary anymore...
        int retry = 0;
        while (retry < 5)
        {
            // Open the connexion
            try
            {
                URLConnection urlcon = theURL.openConnection();

                // Set to have input and output and no cache
                if (parameters != null)
                {
                    urlcon.setDoInput(true);
                }
                urlcon.setDoOutput(true);
                urlcon.setUseCaches(false);

                // Work around a Netscape bug
                urlcon.setRequestProperty(
                        "Content-Type",
                        "application/x-www-form-urlencoded");

                // Perform a doPost request to the server
                if (parameters != null)
                {
                    DataOutputStream ostream = new DataOutputStream(urlcon.getOutputStream());
                    ostream.writeBytes(parameters);
                    ostream.flush();
                    ostream.close();
                }

                // Return the reply
                inputStream = urlcon.getInputStream();


                in = new BufferedInputStream(urlcon.getInputStream(), 4096);
            } catch (IOException ioe)
            {
                System.err.println("Unable to open URL " + url + " (" + ioe.getMessage() + ")");
                retry++;
                try
                {
                    Thread.currentThread().sleep(1000L);
                } catch (InterruptedException i)
                {
                    System.err.println("Interrupted in callHTTPServer()");
                    return null;
                }
                continue;
            }
            // Get the data
            try
            {
                byte[] buffer = new byte[4096];
                int read;

                //a string buffer is about 300! times faster :)
                stringBuff = new StringBuffer(8000);

                while ((read = in.read(buffer, 0, buffer.length)) != -1)
                {
                    if (read > 0)
                        stringBuff.append(new String(buffer, 0, read));
                }
            } catch (IOException ioe)
            {
                System.err.println("Unable to read from URL " + url + " (" + ioe.getMessage() + ")");
                return null;
            } finally
            {
                try
                {
                    if (in != null)
                        in.close();
                } catch (IOException ioe)
                {
                    System.err.println("Unable to close URL " + url + " (" + ioe.getMessage() + ")");
                }
            }
            // No retry at this point
            break;
        }
        return stringBuff.toString();
    }
}
